Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1328)

Unified Diff: remoting/host/fake_desktop_capturer.h

Issue 455073004: Switch DesktopEnvironment to return a DesktopCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove ShapedDesktopCapturer::Create() Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/desktop_session_proxy.cc ('k') | remoting/host/fake_desktop_capturer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/fake_desktop_capturer.h
diff --git a/remoting/host/fake_screen_capturer.h b/remoting/host/fake_desktop_capturer.h
similarity index 51%
rename from remoting/host/fake_screen_capturer.h
rename to remoting/host/fake_desktop_capturer.h
index 2fd59cc2f95dc5af474dbcd4b32045ac5c0d1663..a6881e651bd7f76eef6cbed94395eece1339617f 100644
--- a/remoting/host/fake_screen_capturer.h
+++ b/remoting/host/fake_desktop_capturer.h
@@ -2,34 +2,34 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef REMOTING_HOST_FAKE_SCREEN_CAPTURER_H_
-#define REMOTING_HOST_FAKE_SCREEN_CAPTURER_H_
+#ifndef REMOTING_HOST_FAKE_DESKTOP_CAPTURER_H_
+#define REMOTING_HOST_FAKE_DESKTOP_CAPTURER_H_
#include "base/callback.h"
#include "base/memory/scoped_ptr.h"
#include "media/base/media_export.h"
+#include "third_party/webrtc/modules/desktop_capture/desktop_capturer.h"
#include "third_party/webrtc/modules/desktop_capture/desktop_geometry.h"
#include "third_party/webrtc/modules/desktop_capture/screen_capture_frame_queue.h"
-#include "third_party/webrtc/modules/desktop_capture/screen_capturer.h"
namespace remoting {
// A FakeScreenCapturer generates artificial image for testing purpose.
//
-// FakeScreenCapturer is double-buffered as required by ScreenCapturer.
-class FakeScreenCapturer : public webrtc::ScreenCapturer {
+// FakeDesktopCapturer is double-buffered as required by DesktopCapturer.
+class FakeDesktopCapturer : public webrtc::DesktopCapturer {
public:
// By default FakeScreenCapturer generates frames of size kWidth x kHeight,
// but custom frame generator set using set_frame_generator() may generate
// frames of different size.
static const int kWidth = 800;
static const int kHeight = 600;
typedef base::Callback<scoped_ptr<webrtc::DesktopFrame>(
- webrtc::ScreenCapturer::Callback* callback)> FrameGenerator;
+ webrtc::DesktopCapturer::Callback* callback)> FrameGenerator;
- FakeScreenCapturer();
- virtual ~FakeScreenCapturer();
+ FakeDesktopCapturer();
+ virtual ~FakeDesktopCapturer();
void set_frame_generator(const FrameGenerator& frame_generator);
@@ -37,21 +37,14 @@ class FakeScreenCapturer : public webrtc::ScreenCapturer {
virtual void Start(Callback* callback) OVERRIDE;
virtual void Capture(const webrtc::DesktopRegion& rect) OVERRIDE;
- // webrtc::ScreenCapturer interface.
- virtual void SetMouseShapeObserver(
- MouseShapeObserver* mouse_shape_observer) OVERRIDE;
- virtual bool GetScreenList(ScreenList* screens) OVERRIDE;
- virtual bool SelectScreen(webrtc::ScreenId id) OVERRIDE;
-
private:
FrameGenerator frame_generator_;
Callback* callback_;
- MouseShapeObserver* mouse_shape_observer_;
- DISALLOW_COPY_AND_ASSIGN(FakeScreenCapturer);
+ DISALLOW_COPY_AND_ASSIGN(FakeDesktopCapturer);
};
} // namespace remoting
-#endif // REMOTING_HOST_FAKE_SCREEN_CAPTURER_H_
+#endif // REMOTING_HOST_FAKE_DESKTOP_CAPTURER_H_
« no previous file with comments | « remoting/host/desktop_session_proxy.cc ('k') | remoting/host/fake_desktop_capturer.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -2,34 +2,34 @@
namespace remoting {
-// A FakeScreenCapturer generates artificial image for testing purpose.
+// A FakeDesktopCapturer generates artificial image for testing purpose.
//
@@ -2,34 +2,34 @@
public:
- // By default FakeScreenCapturer generates frames of size kWidth x kHeight,
+ // By default FakeDesktopCapturer generates frames of size kWidth x kHeight,
// but custom frame generator set using set_frame_generator() may generate
// frames of different size.
This is Rietveld 408576698